Douglas - Parfyme, kosmetikk, toalettsaker, sminke, parfyme og beauty trender

Gå til hovednavigasjon Gå til hovedinnhold

- 2 gratis vareprøver
- Gratis frakt over NOK 600,-
- Leveringstid er 3 til 5 virkedager
- Gratis gaveinnpakkning

Din handlekurv produkter i handlekurven. NOK 0,00 0

- HJEM
- Parfyme
- Pleie
- Makeup
- Hår
- SALG
- Merker

ANBEFALINGER

- Til Julebutikken
- Parfyme
- Hudpleie
- Makeup
- Våre merker
- Nyhetsbrev
- Last ned Douglas APP

Zurück Weiter
Forrige Neste

### OUR FAVORITES

- Make-up Studio Leppestift Leppestift

  NOK 248,00 / 1 eske

- Benefit Sett Make-up sett

  NOK 663,00 / 1 eske

- Guerlain L'Homme Ideal Eau de Toilette (EdT)

  NOK 618,00 / 50 ml

- Lee Stafford Argan Oil Hår olje

  NOK 178,00 / 50 ml

- Artdeco Rouge Rouge

  NOK 198,00 / 10 g

- FOREO LUNA Multi-funksjon enhet

  NOK 1 674,00 / 1 eske

- Hugo Boss Boss Ma Vie Duft sett

  NOK 480,00 / 1 eske

- OPI Venice Collection Neglelakk sett

  NOK 176,00 / 1 eske

- Bvlgari Aqva pour Homme Marine Deodorant stick

  NOK 297,00 / 75 g

#### NYHET: NYX

#### STAR PRODUCTS

####

####

####

### DOUGLAS SERVICE

# Parfyme, makeup, hudpleie og hårpleie: douglas.no dekker alle dine skjønnhetsbehov på nett

Douglas.no gir deg Norges største utvalg av dufter, kosmetikk og pleieprodukter. Vi tilbyr kun autoriserte produkter fra norske og europeiske leverandører. Douglas er Europas største parfymerikjede og nettbutikk, vi kan derfor gi deg produkter fra verdens ledende merkevarer opptil 10% under veiledende priser i Norge. Douglas Nordic AS er et norsk selskap og du betaler derfor ikke toll på varer du kjøper hos oss. Alle priser er inkludert moms.

Douglas.no gir deg gratis frakt på alle ordre over 600 kroner, og for mindre ordre betaler du kun et fast fraktgebyr på kroner 45,- Alle ordre leveres innen 3-5 virkedager. Meld deg på vårt nyhetsbrev og få oppdateringer, spesialtilbud, tips og nyheter først.

Som "Your partner in Beauty" tilbyr våre eksperter gratis hudpleieanalyse og duft- og makeup-konsultasjon i vår butikk. Du kan også få råd og tips tilpasset dine behov ved å sende en e-post til våre skjønnhetskonsulenter på kundeservice@douglas.no eller ved å ringe 815 24 711.

- Registrer en kundekonto
- Nyhetsbrev
- Butikken i Bogstadveien 10
- Frakt og levering

TILBAKE